@@ -3,17 +3,41 @@
 #include <qpdf/QTC.hh>
 #include <qpdf/QUtil.hh>
 
-Pl_RunLength::Members::Members(action_e action) :
-    action(action),
-    state(st_top),
-    length(0)
+namespace
 {
-}
+    unsigned long long memory_limit{0};
+} // namespace
+
+class Pl_RunLength::Members
+{
+  public:
+    Members(action_e action) :
+        action(action)
+    {
+    }
+    Members(Members const&) = delete;
+    ~Members() = default;
+
+    action_e action;
+    state_e state{st_top};
+    unsigned char buf[128];
+    unsigned int length{0};
+    std::string out;
+};
 
 Pl_RunLength::Pl_RunLength(char const* identifier, Pipeline* next, action_e action) :
     Pipeline(identifier, next),
-    m(new Members(action))
+    m(std::make_unique<Members>(action))
 {
+    if (!next) {
+        throw std::logic_error("Attempt to create Pl_RunLength with nullptr as next");
+    }
+}
+
+void
+Pl_RunLength::setMemoryLimit(unsigned long long limit)
+{
+    memory_limit = limit;
 }
 
 Pl_RunLength::~Pl_RunLength() // NOLINT (modernize-use-equals-default)
@@ -66,8 +90,12 @@ Pl_RunLength::encode(unsigned char const* data, size_t len)
 void
 Pl_RunLength::decode(unsigned char const* data, size_t len)
 {
+    if (memory_limit && (len + m->out.size()) > memory_limit) {
+        throw std::runtime_error("Pl_RunLength memory limit exceeded");
+    }
+    m->out.reserve(len);
     for (size_t i = 0; i < len; ++i) {
-        unsigned char ch = data[i];
+        unsigned char const& ch = data[i];
         switch (m->state) {
         case st_top:
             if (ch < 128) {
@@ -85,16 +113,14 @@ Pl_RunLength::decode(unsigned char const* data, size_t len)
             break;
 
         case st_copying:
-            this->getNext()->write(&ch, 1);
+            m->out.append(1, static_cast<char>(ch));
             if (--m->length == 0) {
                 m->state = st_top;
             }
             break;
 
         case st_run:
-            for (unsigned int j = 0; j < m->length; ++j) {
-                this->getNext()->write(&ch, 1);
-            }
+            m->out.append(m->length, static_cast<char>(ch));
             m->state = st_top;
             break;
         }
@@ -120,12 +146,12 @@ Pl_RunLength::flush_encode()
             throw std::logic_error("Pl_RunLength: invalid length in flush_encode for run");
         }
         auto ch = static_cast<unsigned char>(257 - m->length);
-        this->getNext()->write(&ch, 1);
-        this->getNext()->write(&m->buf[0], 1);
+        next()->write(&ch, 1);
+        next()->write(&m->buf[0], 1);
     } else if (m->length > 0) {
         auto ch = static_cast<unsigned char>(m->length - 1);
-        this->getNext()->write(&ch, 1);
-        this->getNext()->write(m->buf, m->length);
+        next()->write(&ch, 1);
+        next()->write(m->buf, m->length);
     }
     m->state = st_top;
     m->length = 0;
@@ -140,7 +166,12 @@ Pl_RunLength::finish()
     if (m->action == a_encode) {
         flush_encode();
         unsigned char ch = 128;
-        this->getNext()->write(&ch, 1);
+        next()->write(&ch, 1);
+    } else {
+        if (memory_limit && (m->out.size()) > memory_limit) {
+            throw std::runtime_error("Pl_RunLength memory limit exceeded");
+        }
+        next()->writeString(m->out);
     }
-    this->getNext()->finish();
+    next()->finish();
 }
